@@ -265,13 +265,18 @@ class PreparePipes(object):
         content_type = line_group['content_type'].value
 
         pipes_field_names = [
-            'pk', 'display_name',
+            'pk',
+            'display_name',
             'invert_level_start_point',
             'invert_level_end_point',
-            'friction_type', 'friction_value',
-            'sewerage_type', 'calculation_type',
+            'friction_type',
+            'friction_value',
+            'material',
+            'sewerage_type',
+            'calculation_type',
             'connection_node_start_pk',
-            'connection_node_end_pk', 'zoom_category',
+            'connection_node_end_pk',
+            'zoom_category',
             'cross_section_definition__db_width',
             'cross_section_definition__db_height',
             'cross_section_definition__db_shape']
@@ -301,14 +306,27 @@ class PrepareWeirs(object):
         content_type = line_group['content_type'].value
 
         weirs_field_names = [
-            'pk', 'code', 'display_name',
+            'pk',
+            'code',
+            'display_name',
             'discharge_coefficient_negative',
             'discharge_coefficient_positive',
-            'sewerage', 'friction_type', 'friction_value',
-            'crest_type', 'crest_level',
-            'connection_node_start_pk', 'connection_node_end_pk',
-            'zoom_category'
-        ]
+            'sewerage',
+            'friction_type',
+            'friction_value',
+            'crest_type',
+            'crest_level',
+            'connection_node_start_pk',
+            'connection_node_end_pk',
+            'zoom_category',
+            'cross_section_definition__db_width',
+            'cross_section_definition__db_height',
+            'cross_section_definition__db_shape']
+
+        weir_field_name_override = {
+            'cross_section_definition__db_width': 'cross_section_width',
+            'cross_section_definition__db_height': 'cross_section_height',
+            'cross_section_definition__db_shape': 'cross_section_shape'}
 
         weirs_numpy_array_dict = db_objects_to_numpy_array_dict(
             threedi_datasource.v2_weirs, weirs_field_names)
@@ -317,7 +335,9 @@ class PrepareWeirs(object):
             line_group, weirs_numpy_array_dict,
             weirs_field_names,
             weirs_numpy_array_dict['pk'], content_pk,
-            ignore_mask=content_type != 'v2_weir')
+            ignore_mask=content_type != 'v2_weir',
+            field_name_override=weir_field_name_override
+        )
 
 
 class PrepareOrifices(object):
@@ -329,12 +349,17 @@ class PrepareOrifices(object):
         content_type = line_group['content_type'].value
 
         orifices_field_names = [
-            'pk', 'display_name', 'sewerage',
-            'friction_type', 'friction_value',
+            'pk',
+            'display_name',
+            'sewerage',
+            'friction_type',
+            'friction_value',
             'discharge_coefficient_negative',
             'discharge_coefficient_positive',
-            'crest_type', 'crest_level',
-            'connection_node_start_pk', 'connection_node_end_pk',
+            'crest_type',
+            'crest_level',
+            'connection_node_start_pk',
+            'connection_node_end_pk',
             'zoom_category'
         ]
 
@@ -357,14 +382,19 @@ class PrepareCulverts(object):
         content_type = line_group['content_type'].value
 
         culverts_field_names = [
-            'pk', 'code', 'display_name',
+            'pk',
+            'code',
+            'display_name',
             'discharge_coefficient_negative',
             'discharge_coefficient_positive',
-            'friction_type', 'friction_value',
+            'friction_type',
+            'friction_value',
             'invert_level_start_point',
             'invert_level_end_point',
-            'calculation_type', 'dist_calc_points',
-            'connection_node_start_pk', 'connection_node_end_pk',
+            'calculation_type',
+            'dist_calc_points',
+            'connection_node_start_pk',
+            'connection_node_end_pk',
             'zoom_category',
             'cross_section_definition__db_width',
             'cross_section_definition__db_height',
