@@ -11,12 +11,24 @@ from threedigrid.numpy_utils import angle_in_degrees
 from threedigrid.numpy_utils import get_bbox_by_point
 from threedigrid.numpy_utils import reshape_flat_array
 from threedigrid.numpy_utils import select_lines_by_bbox
-from threedigrid.geo_utils import select_points_by_tile
+from threedigrid.geo_utils import select_points_by_tile, \
+    select_geoms_by_geometry, raise_import_exception
 from threedigrid.geo_utils import select_lines_by_tile
 from threedigrid.geo_utils import select_points_by_bbox
 from threedigrid.geo_utils import transform_xys
 from six.moves import map
 
+try:
+    from pyproj import Transformer
+except ImportError:
+    Transformer = None
+
+try:
+    import shapely
+    from shapely.geometry import Polygon, Point, asLineString, asPolygon
+except ImportError:
+    shapely = None
+
 
 class GeomArrayField(ArrayField):
     """
@@ -28,6 +40,25 @@ class GeomArrayField(ArrayField):
     def to_centroid(self, values):
         raise NotImplementedError()
 
+    def get_mask_by_geometry(self, geometry, values):
+        geoms = self._to_shapely_geom(values)
+
+        selected_geoms = select_geoms_by_geometry(geoms, geometry)
+
+        mask = np.zeros((len(values.T),), dtype=bool)
+        for geom in selected_geoms:
+            mask[geom.index] = True
+
+        return mask
+
+    def _to_shapely_geom(self, values):
+        """Returns a list of shapely geometries created from values
+
+        :param values: coordinates
+        :return: list of shapely geometries
+        """
+        raise NotImplementedError()
+
 
 class PointArrayField(GeomArrayField):
     def reproject(self, values, source_epsg, target_epsg):
@@ -65,6 +96,17 @@ class PointArrayField(GeomArrayField):
         """
         return values
 
+    def _to_shapely_geom(self, values):
+        if shapely is None:
+            raise_import_exception('shapely')
+
+        points = []
+        for i, coord in enumerate(values.T):
+            point = Point(coord[0], coord[1])
+            point.index = i  # the index is used in get_mask_by_geometry
+            points.append(point)
+        return points
+
 
 class LineArrayField(GeomArrayField):
     """
@@ -136,6 +178,17 @@ class LineArrayField(GeomArrayField):
         return angle_in_degrees(
                 values[0], values[1], values[2], values[3])
 
+    def _to_shapely_geom(self, values):
+        if shapely is None:
+            raise_import_exception('shapely')
+
+        lines = []
+        for i, coords in enumerate(values.T):
+            line = asLineString(coords.reshape((2, -1)))
+            line.index = i  # the index is used in get_mask_by_geometry
+            lines.append(line)
+        return lines
+
 
 class MultiLineArrayField(GeomArrayField):
 
@@ -147,13 +200,41 @@ class MultiLineArrayField(GeomArrayField):
         from source_epsg to target_epsg.
         """
         reshaped_values = list(map(reshape_flat_array, values))
-        transform_values = [
-            transform_xys(x[0], x[1], source_epsg, target_epsg).flatten()
-            for x in reshaped_values
-        ]
+
+        # Pyproj has (a lot) more overhead
+        # from 2.0.1 for reprojecting.
+        # so created the Transform once
+        # and reuse it.
+        if Transformer is not None:
+            # Only use the Transformer if it is present
+            # in Python 3 it works well, however in Python 2.7
+            # it seams to break
+            transformer = Transformer.from_proj(
+                int(source_epsg), int(target_epsg))
+
+            transform_values = [
+                np.array(transformer.transform(x[0], x[1])).flatten()
+                for x in reshaped_values
+            ]
+        else:
+            transform_values = [
+                transform_xys(x[0], x[1], source_epsg, target_epsg).flatten()
+                for x in reshaped_values
+            ]
 
         return np.array(transform_values)
 
+    def _to_shapely_geom(self, values):
+        if shapely is None:
+            raise_import_exception('shapely')
+
+        multilines = []
+        for i, coords in enumerate(values):
+            line = asLineString(coords.reshape((2, -1)).T)
+            line.index = i  # the index is used in get_mask_by_geometry
+            multilines.append(line)
+        return multilines
+
 
 class PolygonArrayField(GeomArrayField):
     """
@@ -186,9 +267,35 @@ class PolygonArrayField(GeomArrayField):
                 ),
         ))
 
+    def _to_shapely_geom(self, values):
+        if shapely is None:
+            raise_import_exception('shapely')
+
+        polygons = []
+        for i, coords in enumerate(values):
+            polygon = asPolygon(coords.reshape((2, -1)).T)
+            polygon.index = i  # the index is used in get_mask_by_geometry
+            polygons.append(polygon)
+        return polygons
+
 
 class BboxArrayField(LineArrayField):
-    """
-    For now handled same as lines.
-    """
-    pass
+
+    def _to_shapely_geom(self, values):
+        if shapely is None:
+            raise_import_exception('shapely')
+
+        polygons = []
+        for i, coord in enumerate(values.T):
+            # convert the bbox bottom-left and upper-right into a polygon
+            polygon = Polygon(
+                [
+                    (coord[0], coord[1]),
+                    (coord[0], coord[3]),
+                    (coord[2], coord[3]),
+                    (coord[2], coord[1])
+                ]
+            )
+            polygon.index = i  # the index is used in get_mask_by_geometry
+            polygons.append(polygon)
+        return polygons
